@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# SelfTest/Hash/test_SHA3_512.py: Self-test for the SHA-3/512 hash function
+# SelfTest/Hash/test_SHA3_384.py: Self-test for the SHA-3/384 hash function
 #
 # ===================================================================
 # The contents of this file are dedicated to the public domain.  To
@@ -20,14 +20,14 @@
 # SOFTWARE.
 # ===================================================================
 
-"""Self-test suite for Crypto.Hash.SHA3_512"""
+"""Self-test suite for Crypto.Hash.SHA3_384"""
 
 import unittest
 from binascii import hexlify
 
-from Crypto.SelfTest.loader import load_tests
+from Crypto.SelfTest.loader import load_test_vectors
 from Crypto.SelfTest.st_common import list_test_cases
-from Crypto.Hash import SHA3_512 as SHA3
+from Crypto.Hash import SHA3_384 as SHA3
 from Crypto.Util.py3compat import b
 
 
@@ -56,10 +56,10 @@ def get_tests(config={}):
 
     tests = []
 
-    test_vectors = load_tests(("Crypto", "SelfTest", "Hash", "test_vectors", "SHA3"),
-                                "ShortMsgKAT_SHA3-512.txt",
-                                "KAT SHA-3 512",
-                                { "len" : lambda x: int(x) } )
+    test_vectors = load_test_vectors(("Hash", "SHA3"),
+                                "ShortMsgKAT_SHA3-384.txt",
+                                "KAT SHA-3 384",
+                                { "len" : lambda x: int(x) } ) or []
 
     test_data = []
     for tv in test_vectors:
@@ -67,9 +67,9 @@ def get_tests(config={}):
             tv.msg = b("")
         test_data.append((hexlify(tv.md), tv.msg, tv.desc))
 
-    tests += make_hash_tests(SHA3, "SHA3_512", test_data,
+    tests += make_hash_tests(SHA3, "SHA3_384", test_data,
                              digest_size=SHA3.digest_size,
-                             oid="2.16.840.1.101.3.4.2.10")
+                             oid="2.16.840.1.101.3.4.2.9")
     tests += list_test_cases(APITest)
     return tests
 
